==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/LivenessAttempts.java <==
package com.example.model;

/**
 * Model for LivenessAttempts
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "LivenessAttempts", description = "Model for LivenessAttempts")
@javax.xml.bind.annotation.XmlRootElement(name = "LivenessAttempts")
public class LivenessAttempts implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<java.lang.String> actions = new java.util.ArrayList<java.lang.String>();
	private java.lang.Boolean result = null;
	private java.lang.String sessionId = null;
	private com.example.model.File video = null;
	
	/**
	 */
	public LivenessAttempts actions(java.util.List<java.lang.String> actions) {
		setActions(actions);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("actions")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<java.lang.String> getActions() {
		return this.actions;
	}
	public void setActions(java.util.List<java.lang.String> actions) {
		this.actions = actions;
	}
	public LivenessAttempts addAction(java.lang.String action) {
		if (this.actions == null) {
			this.actions = new java.util.ArrayList<java.lang.String>();
		}
		this.actions.add(action);
		return this;
	}
	
	/**
	 */
	public LivenessAttempts result(java.lang.Boolean result) {
		setResult(result);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("result")
	public java.lang.Boolean getResult() {
		return this.result;
	}
	public void setResult(java.lang.Boolean result) {
		this.result = result;
	}
	
	/**
	 */
	public LivenessAttempts sessionId(java.lang.String sessionId) {
		setSessionId(sessionId);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("session_id")
	public java.lang.String getSessionId() {
		return this.sessionId;
	}
	public void setSessionId(java.lang.String sessionId) {
		this.sessionId = sessionId;
	}
	
	/**
	 * Model for File
	 */
	public LivenessAttempts video(com.example.model.File video) {
		setVideo(video);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("video")
	@javax.validation.Valid
	public com.example.model.File getVideo() {
		return this.video;
	}
	public void setVideo(com.example.model.File video) {
		this.video = video;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		LivenessAttempts livenessAttempts = (LivenessAttempts) o;
		return java.util.Objects.equals(this.actions, livenessAttempts.actions)
				&& java.util.Objects.equals(this.result, livenessAttempts.result)
				&& java.util.Objects.equals(this.sessionId, livenessAttempts.sessionId)
				&& java.util.Objects.equals(this.video, livenessAttempts.video);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.actions, this.result, this.sessionId, this.video);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class LivenessAttempts {\n");
		
		sb.append("    actions: ").append(toIndentedString(this.actions)).append("\n");
		sb.append("    result: ").append(toIndentedString(this.result)).append("\n");
		sb.append("    sessionId: ").append(toIndentedString(this.sessionId)).append("\n");
		sb.append("    video: ").append(toIndentedString(this.video)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/LivenessAttempts.java <==
package com.example.model;

/**
 * Model for LivenessAttempts
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "LivenessAttempts", description = "Model for LivenessAttempts")
@javax.xml.bind.annotation.XmlRootElement(name = "LivenessAttempts")
public class LivenessAttempts implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.util.List<java.lang.String> actions = new java.util.ArrayList<java.lang.String>();
	private java.lang.Boolean result = null;
	private java.lang.String sessionId = null;
	private com.example.model.File video = null;
	
	/**
	 */
	public LivenessAttempts actions(java.util.List<java.lang.String> actions) {
		setActions(actions);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "actions")
	@com.fasterxml.jackson.annotation.JsonProperty("actions")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public java.util.List<java.lang.String> getActions() {
		return this.actions;
	}
	public void setActions(java.util.List<java.lang.String> actions) {
		this.actions = actions;
	}
	public LivenessAttempts addAction(java.lang.String action) {
		if (this.actions == null) {
			this.actions = new java.util.ArrayList<java.lang.String>();
		}
		this.actions.add(action);
		return this;
	}
	
	/**
	 */
	public LivenessAttempts result(java.lang.Boolean result) {
		setResult(result);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "result")
	@com.fasterxml.jackson.annotation.JsonProperty("result")
	public java.lang.Boolean getResult() {
		return this.result;
	}
	public void setResult(java.lang.Boolean result) {
		this.result = result;
	}
	
	/**
	 */
	public LivenessAttempts sessionId(java.lang.String sessionId) {
		setSessionId(sessionId);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "session_id")
	@com.fasterxml.jackson.annotation.JsonProperty("session_id")
	public java.lang.String getSessionId() {
		return this.sessionId;
	}
	public void setSessionId(java.lang.String sessionId) {
		this.sessionId = sessionId;
	}
	
	/**
	 * Model for File
	 */
	public LivenessAttempts video(com.example.model.File video) {
		setVideo(video);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "video", description = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("video")
	@javax.validation.Valid
	public com.example.model.File getVideo() {
		return this.video;
	}
	public void setVideo(com.example.model.File video) {
		this.video = video;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		LivenessAttempts livenessAttempts = (LivenessAttempts) o;
		return java.util.Objects.equals(this.actions, livenessAttempts.actions)
				&& java.util.Objects.equals(this.result, livenessAttempts.result)
				&& java.util.Objects.equals(this.sessionId, livenessAttempts.sessionId)
				&& java.util.Objects.equals(this.video, livenessAttempts.video);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.actions, this.result, this.sessionId, this.video);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class LivenessAttempts {\n");
		
		sb.append("    actions: ").append(toIndentedString(this.actions)).append("\n");
		sb.append("    result: ").append(toIndentedString(this.result)).append("\n");
		sb.append("    sessionId: ").append(toIndentedString(this.sessionId)).append("\n");
		sb.append("    video: ").append(toIndentedString(this.video)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
